@@ -1,4 +1,5 @@
 import inspect
+import logging
 import os
 from sys import path
 from typing import Any, Dict, List
@@ -6,6 +7,10 @@ from typing import Any, Dict, List
 from anyscale import snapshot_util, version
 
 
+logger = logging.getLogger(__name__)
+logger.addHandler(logging.StreamHandler())
+logger.setLevel(os.environ.get("ANYSCALE_LOGLEVEL", "WARN"))
+
 anyscale_dir = os.path.dirname(os.path.abspath(__file__))
 path.append(os.path.join(anyscale_dir, "client"))
 path.append(os.path.join(anyscale_dir, "sdk"))
