@@ -4,7 +4,7 @@ from typing import Any, Dict, List
 
 from anyscale.autoscaler.node_provided_cache import NodeProviderCache
 import anyscale.shared_anyscale_utils.conf as shared_anyscale_conf
-from anyscale.utils.import_ray_util import try_import_ray
+from anyscale.utils.imports.all import try_import_ray
 
 
 try_import_ray()
