@@ -36,7 +36,7 @@ from anyscale.client.openapi_client.models.wait_until_stopped_options import (
     WaitUntilStoppedOptions,
 )
 from anyscale.shared_anyscale_utils.util import get_autoscaler_container_path
-from anyscale.utils.import_ray_util import try_import_ray
+from anyscale.utils.imports.all import try_import_ray
 
 
 try_import_ray()
