@@ -163,9 +163,21 @@ def terminate(job_id: Optional[str], name: Optional[str]) -> None:
 )
 def logs(job_id: Optional[str], name: Optional[str], follow: bool = False,) -> None:
     job_controller = JobController()
-    job_controller.logs(
-        job_id=job_id, job_name=name, should_follow=follow,
-    )
+    try:
+        if follow:
+            job_controller.stream_logs(job_id=job_id, job_name=name)
+            return
+    except Exception as e:
+        log.info(f"Job logs could not be followed due to error: {e}")
+    try:
+        log.info("Now downloading logs from S3...")
+        job_controller.download_logs(job_id=job_id, job_name=name)
+    except Exception as e:
+        log.info(f"Job logs could not be downloaded due to error: {e}")
+        log.info("Now trying default method of fetching logs.")
+        job_controller.logs(
+            job_id=job_id, job_name=name, should_follow=follow,
+        )
 
 
 @job_cli.command(name="wait")
