@@ -12,9 +12,7 @@ log = BlockLogger()  # CLI Logger
 
 
 @click.group(
-    "service",
-    help="Interact with production services running on Anyscale.",
-    hidden=True,
+    "service", help="Interact with production services running on Anyscale.",
 )
 def service_cli() -> None:
     pass
@@ -27,10 +25,7 @@ def service_cli() -> None:
     "--description", required=False, default=None, help="Description of service."
 )
 @click.option(
-    "--healthcheck-url",
-    required=False,
-    default="/healthcheck",
-    help="Description of service.",
+    "--healthcheck-url", required=False, help="Healthcheck URL for Service.",
 )
 @click.argument(
     "entrypoint", required=False, nargs=-1,
