@@ -1,3 +1,4 @@
+import os
 from typing import Optional
 
 
@@ -15,4 +16,8 @@ ANYSCALE_IAM_ROLE_NAME = "anyscale-iam-role"
 # Minimum default Ray version to return when a user either asks for `anyscale.connect required_ray_version`
 # or when a Default Cluster Env is used
 # TODO(ilr/nikita) Convert this to a backend call for the most recent Ray Version in the Dataplane!
-MINIMUM_RAY_VERSION = "1.6.0"
+MINIMUM_RAY_VERSION = "1.7.0"
+
+IDLE_TIMEOUT_DEFAULT_MINUTES = 120
+
+ROOT_DIR_PATH = os.path.dirname(__file__)
