@@ -1,4 +1,5 @@
 from datetime import datetime
+from enum import Enum
 import sys
 import time
 from typing import Any, cast, Dict, List, Optional, Tuple, Union
@@ -22,6 +23,7 @@ from anyscale.sdk.anyscale_client import (
 )
 from anyscale.sdk.anyscale_client.models.cloud import Cloud
 from anyscale.sdk.anyscale_client.models.compute_template import ComputeTemplate
+from anyscale.sdk.anyscale_client.models.session_state import SessionState
 from anyscale.util import generate_slug, get_endpoint, wait_for_session_start
 from anyscale.utils.connect_helpers import get_cluster, list_entities
 
@@ -58,6 +60,14 @@ def _get_base_image(image: str, ray_version: str, cpu_or_gpu: str) -> str:
     return "anyscale/{}:{}-py{}-{}".format(image, ray_version, py_version, cpu_or_gpu)
 
 
+class PrepareClusterAction(str, Enum):
+    START = "START"
+    CREATE = "CREATE"
+    UPDATE = "UPDATE"
+    WAIT = "WAIT"
+    NO_OP = "NO_OP"
+
+
 class PrepareClusterBlock:
     def __init__(
         self,
@@ -107,18 +117,24 @@ class PrepareClusterBlock:
         self.block_label = "PrepareCluster"
         self.log.open_block(self.block_label, block_title="Preparing the cluster")
 
-        needs_start_or_create = self._check_if_cluster_needs_start_or_create(
+    def prepare(self):
+        prepare_cluster_action = self._get_prepare_cluster_action(
             self.project_id, self.cluster_name, self.needs_update
         )
-        if needs_start_or_create:
+
+        if prepare_cluster_action in {
+            PrepareClusterAction.CREATE,
+            PrepareClusterAction.START,
+            PrepareClusterAction.UPDATE,
+        }:
             existing_terminated_cluster = None
             if self.cluster_name:
                 existing_terminated_cluster = get_cluster(
-                    self.anyscale_api_client, project_id, self.cluster_name
+                    self.anyscale_api_client, self.project_id, self.cluster_name
                 )
 
             self.cluster_env_name = self._build_cluster_env_if_needed(
-                project_id,
+                self.project_id,
                 self.build_pr,
                 self.build_commit,
                 self.cluster_env_dict,
@@ -136,7 +152,7 @@ class PrepareClusterBlock:
             else:
                 build_id = existing_terminated_cluster.build_id
 
-            cloud_id = self._get_cloud_id(project_id, self.cloud_name)
+            cloud_id = self._get_cloud_id(self.project_id, self.cloud_name)
             if (
                 (existing_terminated_cluster is not None)
                 and (existing_terminated_cluster.cloud_id is not None)
@@ -173,7 +189,7 @@ class PrepareClusterBlock:
             else:
                 compute_template_id = existing_terminated_cluster.compute_template_id
 
-            self._wait_for_app_build(project_id, build_id)
+            self._wait_for_app_build(self.project_id, build_id)
 
             self.cluster_name = self._start_or_create_cluster(
                 project_id=self.project_id,
@@ -186,22 +202,34 @@ class PrepareClusterBlock:
         else:
             assert (
                 self.cluster_name
-            ), f"{self.cluster_name} is None, yet _check_if_cluster_needs_start_or_create returned False."
+            ), f"{self.cluster_name} is None, yet _derive_prepare_cluster_action returned {prepare_cluster_action}."
             cluster = get_cluster(
                 self.anyscale_api_client, self.project_id, self.cluster_name
             )
             assert (
                 cluster
-            ), f"Cluster {self.cluster_name} not found, yet _check_if_cluster_needs_start_or_create returned False."
+            ), f"Cluster {self.cluster_name} not found, yet _derive_prepare_cluster_action returned {prepare_cluster_action}."
             self._validate_new_cluster_compute_and_env_match_existing_cluster(
                 project_id=self.project_id, running_cluster=cluster,
             )
+            if prepare_cluster_action == PrepareClusterAction.WAIT:
+                cluster = get_cluster(
+                    self.anyscale_api_client, self.project_id, self.cluster_name
+                )
+                wait_for_session_start(
+                    self.project_id,
+                    cluster.name,
+                    self.api_client,
+                    log=self.log,
+                    block_label=self.block_label,
+                )
+
             self.log.info(
                 f"Cluster {BlockLogger.highlight(self.cluster_name)} is currently running.",
                 block_label=self.block_label,
             )
             self.log.info("Connecting to this cluster:", block_label=self.block_label)
-            url = get_endpoint(f"/projects/{project_id}/clusters/{cluster.id}")
+            url = get_endpoint(f"/projects/{self.project_id}/clusters/{cluster.id}")
             self._log_cluster_configs(
                 cluster, cluster.build_id, cluster.compute_template_id, url,
             )
@@ -482,27 +510,27 @@ class PrepareClusterBlock:
 
         return cluster, start_required
 
-    def _check_if_cluster_needs_start_or_create(
+    def _get_prepare_cluster_action(
         self, project_id: str, cluster_name: Optional[str], needs_update: bool
-    ):
-        """Returns True if the cluster needs to be started/updated/created or else returns False.
-        Returns False only when the cluster is currently running and the user did not
-        explicitly pass an update request (`.cluster_env(..., update=True)`).
+    ) -> PrepareClusterAction:
         """
-        if cluster_name:
-            cluster = get_cluster(self.anyscale_api_client, project_id, cluster_name)
-            if not cluster:
-                # Unconditionally create the cluster if it isn't up.
-                needs_start_or_create = True
-            elif cluster.state != "Running":
-                # Unconditionally create the cluster if it isn't up.
-                needs_start_or_create = True
-            else:
-                needs_start_or_create = needs_update
+        Returns the next cluster action based on the cluster state.
+        """
+        if not cluster_name:
+            return PrepareClusterAction.CREATE
+        cluster = get_cluster(self.anyscale_api_client, project_id, cluster_name)
+        if not cluster:
+            # Unconditionally create the cluster if it isn't up.
+            return PrepareClusterAction.CREATE
+        elif cluster.state == SessionState.STARTINGUP:
+            return PrepareClusterAction.WAIT
+        elif cluster.state != SessionState.RUNNING:
+            # Unconditionally start the cluster if it isn't up.
+            return PrepareClusterAction.START
+        elif needs_update:
+            return PrepareClusterAction.UPDATE
         else:
-            needs_start_or_create = True
-
-        return needs_start_or_create
+            return PrepareClusterAction.NO_OP
 
     def _get_default_cluster_env_build(self) -> Build:
         """
@@ -1007,7 +1035,7 @@ def create_prepare_cluster_block(
     is not a global variable an will be reinstantiated on each call to
     get_prepare_cluster_block.
     """
-    return PrepareClusterBlock(
+    prepare_cluster_block = PrepareClusterBlock(
         project_id=project_id,
         cluster_name=cluster_name,
         autosuspend_timeout=autosuspend_timeout,
@@ -1025,3 +1053,5 @@ def create_prepare_cluster_block(
         ray=ray,
         log_output=log_output,
     )
+    prepare_cluster_block.prepare()
+    return prepare_cluster_block
