@@ -258,7 +258,8 @@ class StartInteractiveSessionBlock:
                 connect_kwargs["ray_init_kwargs"] = ray_init_kwargs
 
             # Ignore non-error messages from ray.util.connect
-            logging.basicConfig(level=logging.ERROR)
+            ray_logger = logging.getLogger("ray")
+            ray_logger.setLevel(logging.ERROR)
 
             # Connect without job config first to get version info. Ray 1.7's
             # job config implementation hangs on Ray 1.6, and Ray 1.8 runtime
