@@ -62,6 +62,7 @@ from anyscale.util import (  # pylint:disable=private-import
     launch_gcp_cloud_setup,
     prepare_cloudformation_template,
 )
+from anyscale.utils.imports.gcp import try_import_gcp_discovery
 
 
 ROLE_CREATION_RETRIES = 30
@@ -349,6 +350,7 @@ class CloudController(BaseController):
         aws_security_groups = [cfn_resources["AnyscaleSecurityGroup"]]
         aws_s3_id = cfn_resources["S3Bucket"]
         aws_efs_id = cfn_resources["EFS"]
+        aws_efs_mount_target_ip = cfn_resources["EFSMountTargetIP"]
         anyscale_iam_role_arn = cfn_resources["AnyscaleIAMRole"]
 
         create_cloud_resource = CreateCloudResource(
@@ -358,6 +360,7 @@ class CloudController(BaseController):
             aws_security_groups=aws_security_groups,
             aws_s3_id=aws_s3_id,
             aws_efs_id=aws_efs_id,
+            aws_efs_mount_target_ip=aws_efs_mount_target_ip,
             aws_cloudformation_stack_id=cfn_stack["StackId"],
         )
 
@@ -775,11 +778,12 @@ class CloudController(BaseController):
         self, cloud: CloudWithCloudResource, write_permissions: bool, yes: bool
     ) -> None:
         import google.auth
-        import googleapiclient.discovery
         from oauth2client.client import GoogleCredentials
 
+        discovery = try_import_gcp_discovery()
+
         credentials = GoogleCredentials.get_application_default()
-        projects_client = googleapiclient.discovery.build(
+        projects_client = discovery.build(
             "cloudresourcemanager", "v3", credentials=credentials
         ).projects()
 
@@ -856,7 +860,7 @@ class CloudController(BaseController):
             f"Successfully updated the IAM policy for projects/{project_name}."
         )
 
-        serviceusage_resource = googleapiclient.discovery.build(
+        serviceusage_resource = discovery.build(
             "serviceusage", "v1", credentials=credentials
         )
         api_state = (
@@ -911,17 +915,15 @@ class CloudController(BaseController):
             return False
 
         if cloud.provider == "AWS":
-            cloud_resource = CreateCloudResource(
-                aws_vpc_id=cloud.cloud_resource.aws_vpc_id,
-                aws_subnet_ids=cloud.cloud_resource.aws_subnet_ids,
-                aws_iam_role_arns=cloud.cloud_resource.aws_iam_role_arns,
-                aws_security_groups=cloud.cloud_resource.aws_security_groups,
-                aws_s3_id=cloud.cloud_resource.aws_s3_id,
-                aws_efs_id=cloud.cloud_resource.aws_efs_id,
-                aws_cloudformation_stack_id=cloud.cloud_resource.aws_cloudformation_stack_id,
-            )
-            return self.verifiy_aws_cloud_resources(
-                cloud_resource, cloud.region, cloud.is_bring_your_own_resource
+            boto3_session = boto3.Session(region_name=cloud.region)
+            return self.verify_aws_cloud_resources(
+                cloud_resource=cloud.cloud_resource,
+                boto3_session=boto3_session,
+                region=cloud.region,
+                is_private_network=cloud.is_private_cloud
+                if cloud.is_private_cloud
+                else False,
+                is_bring_your_own_resource=cloud.is_bring_your_own_resource,
             )
 
         elif cloud.provider == "GCP":
@@ -933,14 +935,15 @@ class CloudController(BaseController):
             )
             return False
 
-    def verifiy_aws_cloud_resources(
+    def verify_aws_cloud_resources(
         self,
         cloud_resource: CreateCloudResource,
+        boto3_session: Any,
         region: str,
+        is_private_network: bool,
         is_bring_your_own_resource: bool = False,
         ignore_capacity_errors: bool = IGNORE_CAPACITY_ERRORS,
     ):
-        boto3_session = boto3.Session(region_name=region)
         verify_aws_vpc_result = verify_aws_vpc(
             cloud_resource=cloud_resource,
             boto3_session=boto3_session,
@@ -952,6 +955,7 @@ class CloudController(BaseController):
             region=region,
             logger=self.log,
             ignore_capacity_errors=ignore_capacity_errors,
+            is_private_network=is_private_network,
         )
         if reordered_cloud_resource:
             cloud_resource = reordered_cloud_resource
@@ -960,6 +964,7 @@ class CloudController(BaseController):
         )
         verify_aws_iam_roles_result = verify_aws_iam_roles(
             cloud_resource=cloud_resource,
+            boto3_session=boto3_session,
             region=region,
             anyscale_aws_account=anyscale_aws_account,
             logger=self.log,
@@ -1022,6 +1027,7 @@ class CloudController(BaseController):
         instance_iam_role_id: str,
         security_group_ids: List[str],
         s3_bucket_id: str,
+        private_network: bool,
     ):
         # Create a cloud without cloud resources first
         try:
@@ -1032,6 +1038,7 @@ class CloudController(BaseController):
                     credentials=anyscale_iam_role_id,
                     name=name,
                     is_bring_your_own_resource=True,
+                    is_private_cloud=private_network,
                 )
             )
             cloud_id = created_cloud.result.id
@@ -1056,6 +1063,7 @@ class CloudController(BaseController):
             role.AssumeRolePolicy().update(PolicyDocument=json.dumps(new_policy))
 
             # Verify cloud resources meet our requirement
+            boto3_session = boto3.Session(region_name=region)
             create_cloud_resource = CreateCloudResource(
                 aws_vpc_id=vpc_id,
                 aws_subnet_ids=subnet_ids,
@@ -1066,8 +1074,12 @@ class CloudController(BaseController):
             )
 
             with self.log.spinner("Verifying cloud resources..."):
-                if not self.verifiy_aws_cloud_resources(
-                    create_cloud_resource, region, is_bring_your_own_resource=True
+                if not self.verify_aws_cloud_resources(
+                    cloud_resource=create_cloud_resource,
+                    boto3_session=boto3_session,
+                    region=region,
+                    is_bring_your_own_resource=True,
+                    is_private_network=private_network,
                 ):
                     raise ClickException(
                         "Cloud registration failed! Please make sure all the resources provided meet the requirements and try again."
