@@ -110,6 +110,14 @@ class ClusterController(BaseController):
         project_id, cluster_name = self._get_project_id_and_cluster_name(
             cluster_id, project_id, cluster_name, project_name
         )
+        cluster_list = self.anyscale_api_client.search_clusters(
+            {
+                "project_id": project_id,
+                "name": {"equals": cluster_name},
+                "archive_status": "ALL",
+            }
+        ).results
+        existing_cluster = cluster_list[0] if len(cluster_list) > 0 else None
 
         if docker is not None:
             assert cluster_env_name is None
@@ -123,7 +131,11 @@ class ClusterController(BaseController):
 
         cluster_env, build = self._get_cluster_env_and_build(cluster_env_name)
         cluster_compute = self._get_cluster_compute(
-            cluster_compute_name, cluster_compute_file, cloud_name, project_id
+            cluster_compute_name,
+            cluster_compute_file,
+            cloud_name,
+            existing_cluster,
+            project_id,
         )
         cloud_name = self.anyscale_api_client.get_cloud(
             cluster_compute.config.cloud_id
@@ -133,6 +145,7 @@ class ClusterController(BaseController):
         passed_cluster_env = bool(cluster_env_name)
         passed_cluster_compute = bool(cluster_compute_name or cluster_compute_file)
         cluster, needs_start = self._create_or_update_cluster_data(
+            existing_cluster,
             cluster_name,
             project_id,
             build,
@@ -413,6 +426,7 @@ class ClusterController(BaseController):
         cluster_compute_name: Optional[str],
         cluster_compute_file: Optional[str],
         cloud_name: Optional[str],
+        existing_cluster: Optional[Cluster],
         project_id: str,
     ) -> ComputeTemplate:
         if cluster_compute_name:
@@ -427,6 +441,10 @@ class ClusterController(BaseController):
             cluster_compute = self.anyscale_api_client.create_cluster_compute(
                 CreateClusterCompute(name=name, config=cluster_compute_config)
             ).result
+        elif not cloud_name and existing_cluster:
+            cluster_compute = self.anyscale_api_client.get_cluster_compute(
+                existing_cluster.cluster_compute_id
+            ).result
         else:
             cluster_compute = get_default_cluster_compute(
                 cloud_name, project_id, self.api_client, self.anyscale_api_client
@@ -452,6 +470,7 @@ class ClusterController(BaseController):
 
     def _create_or_update_cluster_data(
         self,
+        existing_cluster: Optional[Cluster],
         cluster_name: str,
         project_id: str,
         build: ClusterEnvironmentBuild,
@@ -466,16 +485,7 @@ class ClusterController(BaseController):
         update the idle timeout of the existing cluster if necessary. Returns Cluster object
         and whether this cluster needs to be started.
         """
-        cluster_list = self.anyscale_api_client.search_clusters(
-            {
-                "project_id": project_id,
-                "name": {"equals": cluster_name},
-                "archive_status": "ALL",
-            }
-        ).results
-
-        cluster_exists = len(cluster_list) > 0
-        if not cluster_exists:
+        if not existing_cluster:
             # Create a new cluster if there is no existing cluster with the given cluster_name
 
             create_cluster_data = {
@@ -495,7 +505,7 @@ class ClusterController(BaseController):
             needs_start = True
         else:
             # Get the existing session and update the idle_timeout if required
-            cluster = cluster_list[0]
+            cluster = existing_cluster
             needs_start = self._check_needs_start(
                 cluster,
                 build,
