@@ -73,17 +73,17 @@ class ClusterEnvController(BaseController):
         else:
             return self._list_cluster_envs(include_shared, max_items)
 
-    def get(self, cluster_env_name: Optional[str], build_id: Optional[str],) -> None:
+    def get(self, cluster_env_name: Optional[str], build_id: Optional[str]) -> None:
         if int(cluster_env_name is not None) + int(build_id is not None) != 1:
             raise click.ClickException(
-                "Please only provide one of `cluster-env-name` or `--build-id`."
+                "Please only provide one of `cluster-env-name` or `--cluster-env-build-id`."
             )
         if cluster_env_name:
             build = get_build_from_cluster_env_identifier(
                 cluster_env_name, self.anyscale_api_client
             )
         config = self.api_client.get_build_api_v2_builds_build_id_get(
-            build.id
+            build_id or build.id
         ).result.config_json
         # TODO(nikita): Improve formatting here
         print(config)
