@@ -26,7 +26,7 @@ from anyscale.util import (
     get_ray_and_py_version_for_default_cluster_env,
 )
 from anyscale.utils.cloud_utils import get_default_cloud
-from anyscale.utils.import_ray_util import try_import_ray
+from anyscale.utils.imports.all import try_import_ray
 from anyscale.utils.ray_version_checker import detect_python_minor_version
 
 
