@@ -1,4 +1,5 @@
 from abc import ABC, abstractmethod
+import asyncio
 from datetime import datetime, timedelta
 import json
 import os
@@ -8,6 +9,7 @@ import traceback
 from typing import Any, cast, Dict, List, Optional, Tuple, Type, Union
 from urllib.parse import urlparse
 
+from aiohttp import ClientSession, WSMsgType
 import click
 from pydantic import BaseModel, Field, root_validator
 import requests
@@ -28,6 +30,7 @@ from anyscale.client.openapi_client import (
 from anyscale.client.openapi_client.models.create_internal_production_job import (
     CreateInternalProductionJob,
 )
+from anyscale.client.openapi_client.models.log_filter import LogFilter
 from anyscale.cluster_compute import (
     get_cluster_compute_from_name,
     get_default_cluster_compute,
@@ -39,6 +42,7 @@ from anyscale.cluster_env import (
     validate_successful_build,
 )
 from anyscale.controllers.base_controller import BaseController
+from anyscale.controllers.logs_controller import LogsController
 from anyscale.project import get_proj_id_from_name, infer_project_id
 from anyscale.shared_anyscale_utils.utils.byod import BYODInfo
 from anyscale.util import (
@@ -527,6 +531,7 @@ class JobController(BaseController):
         super().__init__(initialize_auth_api_client=initialize_auth_api_client)
         self.log = log
         self.log.open_block("Output")
+        self.logs_controller = LogsController()
 
     def submit(
         self,
@@ -902,7 +907,7 @@ class JobController(BaseController):
         ).result
         return jobs_resp
 
-    def _get_latest_job_run(self, job_id: str) -> Any:
+    def _get_latest_job_run(self, job_id: str) -> DecoratedProductionJob:
         job_object = self.api_client.get_job_api_v2_decorated_ha_jobs_production_job_id_get(
             production_job_id=job_id
         ).result
@@ -955,6 +960,43 @@ class JobController(BaseController):
                 else:
                     return
 
+    def stream_logs(
+        self, job_id: Optional[str] = None, job_name: Optional[str] = None,
+    ) -> None:
+        job_id = cast(str, self._resolve_job_object(job_id, job_name).id)
+        job_run_id = self._wait_for_a_job_run(job_id)
+        websocket_url: str = self.api_client.get_job_logs_stream_api_v2_logs_job_logs_stream_job_id_get(
+            job_id=job_run_id
+        ).result.stream_url
+
+        # Implementation is same as
+        # https://github.com/ray-project/ray/blob/6142f52ada995b7123ea7347a70613ca7b924e0c/dashboard/modules/job/sdk.py#L426
+        # However Ray is only part of [all] install, so we replicate the functionality here.
+        async def read_websocket() -> None:
+            async with ClientSession().ws_connect(websocket_url) as ws:
+                while True:
+                    msg = await ws.receive()
+                    if msg.type == WSMsgType.TEXT:
+                        self.log.log(msg.data.strip())
+                    elif msg.type == WSMsgType.CLOSED:
+                        break
+                    elif msg.type == WSMsgType.ERROR:
+                        pass
+
+        asyncio.run(read_websocket())
+
+    def download_logs(
+        self, job_id: Optional[str] = None, job_name: Optional[str] = None,
+    ) -> None:
+        job_id = cast(str, self._resolve_job_object(job_id, job_name).id)
+        prod_job = self._get_latest_job_run(job_id)
+        if prod_job.last_job_run is not None:
+            cluster_id_of_latest_job_run = prod_job.last_job_run.cluster_id
+        else:
+            cluster_id_of_latest_job_run = prod_job.state.cluster_id
+        filter = LogFilter(cluster_id=cluster_id_of_latest_job_run, glob="/job-driver-")
+        self.logs_controller.download_logs(filter=filter, write_to_stdout=True)
+
     def logs(
         self,
         job_id: Optional[str] = None,
