@@ -1,3 +1,4 @@
+import os
 import sys
 from time import sleep, time
 from typing import Any, Dict, Optional, Union
@@ -52,8 +53,12 @@ IN_PROGRESS_BUILD_STATES = [ClusterEnvironmentBuildStatus.IN_PROGRESS, ClusterEn
 
 class AnyscaleSDK(DefaultApi):  # type: ignore
     def __init__(
-        self, auth_token: Optional[str] = None, host: str = "https://api.anyscale.com",
+        self, auth_token: Optional[str] = None, host: Optional[str] = None,
     ):
+        # Default host to production but respect the ANYSCALE_HOST environment variable.
+        if host is None:
+            host = os.environ.get("ANYSCALE_HOST", "https://api.anyscale.com")
+
         # Special handling for `console.` host names
         if host.startswith("https://console."):
             host = host.replace("console.", "api.", 1)
