@@ -8,11 +8,10 @@ import tempfile
 import time
 from typing import Any, Dict, Optional, Tuple
 
-from anyscale.utils.import_ray_util import try_import_ray
+from anyscale.utils.imports.all import try_import_ray
 
 
 logger = logging.getLogger(__name__)
-logging.basicConfig(level=os.environ.get("ANYSCALE_LOGLEVEL", "WARN"))
 
 # Built-in configs.
 WORKING_DIR = os.environ.get("ANYSCALE_WORKING_DIR", "/home/ray")
@@ -696,6 +695,10 @@ def post_build():
 if __name__ == "__main__":
     import sys
 
+    # Since this is also a main script, we need to set the log level here
+    logger.addHandler(logging.StreamHandler())
+    logger.setLevel(os.environ.get("ANYSCALE_LOGLEVEL", "WARN"))
+
     if sys.argv[1] == "snapshot":
         do_snapshot()
     elif sys.argv[1] == "post_build":
