@@ -1,4 +1,6 @@
 import asyncio
+from collections import defaultdict
+import time
 from typing import Dict, List
 
 from anyscale.authenticate import get_auth_api_client
@@ -11,6 +13,7 @@ from anyscale.webterminal.utils import Command
 
 
 KILLED_STATUS_CODE = 130
+MINUTE_IN_SECONDS = 60
 
 
 class CommandPersister:
@@ -29,6 +32,7 @@ class CommandPersister:
         self.session_id = session_id
         self.queue: List[Command] = []
         self.running_commands: Dict[str, Command] = {}
+        self.last_uploaded_time: Dict[str, float] = defaultdict(float)
         self.is_active = True
 
     def shutdown(self) -> None:
@@ -36,6 +40,8 @@ class CommandPersister:
 
     async def persist_commands(self) -> None:
         while self.is_active:
+            for session_command in self.running_commands.values():
+                self.upload_command_log(session_command)
             if len(self.queue) == 0:
                 await asyncio.sleep(1)
                 continue
@@ -75,10 +81,9 @@ class CommandPersister:
                         },
                     )
                     del self.running_commands[cmd.scid]
+                self.upload_command_log(cmd)
                 if cmd.finished:
-                    session_upload_command_logs_impl(
-                        command_id=cmd.scid, cli_token=self.cli_token, host=self.host
-                    )
+                    del self.last_uploaded_time[cmd.scid]
             except Exception as e:
                 with open(f"/tmp/{cmd.scid}.err", "a") as err_file:
                     err_file.write(f"{str(e)}\n")
@@ -88,6 +93,30 @@ class CommandPersister:
             else:
                 await asyncio.sleep(1)
 
+    def upload_command_log(self, session_command: Command) -> None:
+        """
+        We upload logs to S3 if any of the below conditions is true:
+        1. Session command terminates
+        2. Session command runs the first time
+        3. The duration from the last uploaded time is larger than the specified period
+        """
+        current_time_in_s = time.time()
+        if (
+            session_command.finished
+            or current_time_in_s - self.last_uploaded_time[session_command.scid]
+            > MINUTE_IN_SECONDS * 2
+        ):
+            session_upload_command_logs_impl(
+                command_id=session_command.scid,
+                cli_token=self.cli_token,
+                host=self.host,
+            )
+            # We store the timestamp in which logs have been successfully
+            # uploaded to avoid re-uploading large logs that take some time
+            # to upload.
+            finish_upload_time_in_s = time.time()
+            self.last_uploaded_time[session_command.scid] = finish_upload_time_in_s
+
     def enqueue_command(self, cmd: Command) -> None:
         """
             enqueue_command adds a Command object to be persisted to our backend.
