@@ -3,7 +3,10 @@ from unittest.mock import _Call, ANY, call, Mock, patch
 
 import pytest
 
-from anyscale.connect_utils.prepare_cluster import PrepareClusterBlock
+from anyscale.connect_utils.prepare_cluster import (
+    PrepareClusterAction,
+    PrepareClusterBlock,
+)
 from anyscale.sdk.anyscale_client import (
     CreateCluster,
     StartClusterOptions,
@@ -259,7 +262,7 @@ def test_create_or_update_session_data_generates_new_cluster_name(
 @pytest.mark.parametrize("cluster_exists", [True, False])
 @pytest.mark.parametrize("cluster_name", ["test_cluster_name", None])
 @pytest.mark.parametrize("cluster_state", ["Running", "Other"])
-def test_check_if_cluster_needs_start_or_create(
+def test_get_prepare_cluster_action(
     mock_prepare_cluster_block,
     needs_update: bool,
     cluster_exists: bool,
@@ -275,17 +278,17 @@ def test_check_if_cluster_needs_start_or_create(
         return_value=Mock(result=mock_cluster if cluster_exists else None)
     )
 
-    if not cluster_name or cluster_state != "Running" or not cluster_exists:
-        assert mock_prepare_cluster_block._check_if_cluster_needs_start_or_create(
-            "test_project_id", cluster_name, needs_update
-        )
+    prepare_cluster_action = mock_prepare_cluster_block._get_prepare_cluster_action(
+        "test_project_id", cluster_name, needs_update
+    )
+    if not cluster_name or not cluster_exists:
+        assert prepare_cluster_action == PrepareClusterAction.CREATE
+    elif cluster_state != "Running":
+        assert prepare_cluster_action == PrepareClusterAction.START
+    elif needs_update:
+        assert prepare_cluster_action == PrepareClusterAction.UPDATE
     else:
-        assert (
-            mock_prepare_cluster_block._check_if_cluster_needs_start_or_create(
-                "test_project_id", cluster_name, needs_update
-            )
-            == needs_update
-        )
+        assert prepare_cluster_action == PrepareClusterAction.NO_OP
 
     if cluster_name:
         mock_prepare_cluster_block.anyscale_api_client.search_clusters.assert_called_once_with(
@@ -683,22 +686,23 @@ def test_get_all_clouds(mock_prepare_cluster_block) -> None:
     )
 
 
-@pytest.mark.parametrize("cluster_needs_start_or_create", [True, False])
-@pytest.mark.parametrize("cluster_name", ["test_cluster_name", None])
+@pytest.mark.parametrize(
+    "get_prepare_cluster_action",
+    [
+        PrepareClusterAction.CREATE,
+        PrepareClusterAction.START,
+        PrepareClusterAction.NO_OP,
+    ],
+)
 @pytest.mark.parametrize("cluster_compute_name", ["test_cluster_compute_name", None])
 @pytest.mark.parametrize("cluster_env_name", ["test_cluster_env_name", None])
 def test_init(
-    cluster_needs_start_or_create: bool,
-    cluster_name: Optional[str],
+    get_prepare_cluster_action: bool,
     cluster_compute_name: Optional[str],
     cluster_env_name: Optional[str],
 ):
-    if not cluster_needs_start_or_create and not cluster_name:
-        return
-
-    mock_check_if_cluster_needs_start_or_create = Mock(
-        return_value=cluster_needs_start_or_create
-    )
+    cluster_name = "test_cluster_name"
+    mock_get_prepare_cluster_action = Mock(return_value=get_prepare_cluster_action)
     mock_cluster = Mock(
         cloud_id="mock_cloud_id", compute_template_id="mock_cluster_compute_id"
     )
@@ -726,7 +730,7 @@ def test_init(
         _get_cloud_id=mock_get_cloud_id,
         _get_cluster_build=mock_get_cluster_build,
         _build_cluster_env_if_needed=mock_build_cluster_env_if_needed,
-        _check_if_cluster_needs_start_or_create=mock_check_if_cluster_needs_start_or_create,
+        _get_prepare_cluster_action=mock_get_prepare_cluster_action,
     ), patch.multiple(
         "anyscale.connect_utils.prepare_cluster",
         get_cluster=Mock(return_value=mock_cluster),
@@ -749,12 +753,16 @@ def test_init(
             cluster_env_revision=mock_cluster_env_revision,
             ray=Mock(),
         )
+        prepare_cluster_block.prepare()
         assert prepare_cluster_block.cluster_name == "test_cluster_name"
 
-    mock_check_if_cluster_needs_start_or_create.assert_called_once_with(
+    mock_get_prepare_cluster_action.assert_called_once_with(
         "test_project_id", cluster_name, False
     )
-    if cluster_needs_start_or_create:
+    if get_prepare_cluster_action in {
+        PrepareClusterAction.CREATE,
+        PrepareClusterAction.START,
+    }:
         mock_build_cluster_env_if_needed.assert_called_once_with(
             "test_project_id",
             None,
