@@ -7,6 +7,8 @@ from types import SimpleNamespace
 from typing import Any, Dict, List, Optional, Tuple, Type
 from unittest.mock import MagicMock, Mock, mock_open, patch
 
+from aiohttp import ClientSession, WSMsgType
+from asynctest import CoroutineMock
 import click
 import pytest
 import yaml
@@ -14,6 +16,7 @@ import yaml
 from anyscale.client.openapi_client.models.create_internal_production_job import (
     CreateInternalProductionJob,
 )
+from anyscale.client.openapi_client.models.log_filter import LogFilter
 from anyscale.client.openapi_client.models.production_job_config import (
     ProductionJobConfig,
 )
@@ -802,6 +805,73 @@ def fake_log_provider(mode: str) -> Type[LogProvider]:
     return FakeLogProvider
 
 
+# For `async with a() as b:`
+class MockAsyncContextManagerReturnValue(MagicMock):
+    async def __aenter__(self, *args):
+        return self
+
+    async def __aexit__(self, *args):
+        return None
+
+
+def test_stream_logs(mock_auth_api_client) -> None:
+    job_controller = JobController(log=FakeLogger())
+    prodjob_id = "prodjob_123"
+    job_controller._resolve_job_object = Mock(return_value=Mock(id=prodjob_id))  # type: ignore
+    job_id = "job_123"
+    job_controller._wait_for_a_job_run = Mock(return_value=job_id)  # type: ignore
+    job_controller.api_client = Mock(
+        get_job_logs_stream_api_v2_logs_job_logs_stream_job_id_get=Mock(
+            return_value=Mock(result=Mock(stream_url="http://localhost:5000/stream",))
+        )
+    )
+    mock_websocket = MockAsyncContextManagerReturnValue()
+    mock_websocket.receive = CoroutineMock(
+        side_effect=[
+            Mock(type=WSMsgType.TEXT, data=" abc "),
+            Mock(type=WSMsgType.ERROR),
+            Mock(type=WSMsgType.CLOSED),
+        ]
+    )
+    with patch.object(
+        ClientSession, ClientSession.ws_connect.__name__, return_value=mock_websocket
+    ):
+        job_controller.stream_logs(job_id)
+    job_controller._resolve_job_object.assert_called_once_with(job_id, None)
+    job_controller._wait_for_a_job_run.assert_called_once_with(prodjob_id)
+    job_controller.api_client.get_job_logs_stream_api_v2_logs_job_logs_stream_job_id_get.assert_called_once_with(
+        job_id=job_id
+    )
+    assert mock_websocket.receive.call_count == 3
+    assert job_controller.log.logs == ["abc"]  # type: ignore
+
+
+@pytest.mark.parametrize("cluster_id_found_in_last_job_run", [True, False])
+def test_download_logs(
+    mock_auth_api_client, cluster_id_found_in_last_job_run: bool
+) -> None:
+    prodjob_id = "prodjob_123"
+    cluster_id = "session_123"
+    job_controller = JobController(log=FakeLogger())
+    job_controller._resolve_job_object = Mock(return_value=Mock(id=prodjob_id))  # type: ignore
+    if cluster_id_found_in_last_job_run:
+        mock_prod_job = Mock(last_job_run=Mock(cluster_id=cluster_id), state=Mock())
+    else:
+        mock_prod_job = Mock(last_job_run=None, state=Mock(cluster_id=cluster_id))
+    job_controller._get_latest_job_run = Mock(  # type: ignore
+        return_value=mock_prod_job
+    )
+    mock_download_logs = Mock()
+    job_controller.logs_controller.download_logs = mock_download_logs  # type: ignore
+    job_controller.download_logs(prodjob_id)
+    job_controller._resolve_job_object.assert_called_once_with(prodjob_id, None)
+    job_controller._get_latest_job_run.assert_called_once_with(prodjob_id)
+    mock_download_logs.assert_called_once_with(
+        filter=LogFilter(cluster_id=cluster_id, glob="/job-driver-"),
+        write_to_stdout=True,
+    )
+
+
 @pytest.mark.parametrize(
     "mode",
     ["empty", "single", "paginate", "follow", "flush_success", "wait_for_running"],
