@@ -1,5 +1,6 @@
 import json
 import os
+from typing import Optional
 from unittest.mock import Mock, mock_open, patch
 
 import click
@@ -11,8 +12,12 @@ from anyscale.controllers.service_controller import ServiceController
 
 @pytest.mark.parametrize("use_default_project", [True, False])
 @pytest.mark.parametrize("access", ["public", "private"])
+@pytest.mark.parametrize("maximum_uptime_minutes", [60, None])
 def test_update_service(
-    mock_auth_api_client, use_default_project: bool, access: str
+    mock_auth_api_client,
+    use_default_project: bool,
+    access: str,
+    maximum_uptime_minutes: Optional[int],
 ) -> None:
     config_dict = {
         "entrypoint": "mock_entrypoint",
@@ -21,7 +26,8 @@ def test_update_service(
         "healthcheck_url": "mock_healthcheck_url",
         "access": access,
     }
-    service_controller = ServiceController()
+    mock_logger = Mock()
+    service_controller = ServiceController(log=mock_logger)
     if use_default_project:
         mock_infer_project_id = Mock(return_value="mock_default_project_id")
     else:
@@ -34,6 +40,10 @@ def test_update_service(
     ), patch.multiple(
         "anyscale.controllers.service_controller",
         infer_project_id=mock_infer_project_id,
+    ), patch.object(
+        ServiceController,
+        "_get_maximum_uptime_minutes",
+        return_value=maximum_uptime_minutes,
     ), patch.multiple(
         "anyscale.controllers.job_controller",
         validate_successful_build=mock_validate_successful_build,
@@ -62,6 +72,7 @@ def test_update_service(
             access=access,
         )
     )
+    assert mock_logger.info.call_count == 4
 
 
 def test_service_submit_parse_logic(mock_auth_api_client) -> None:
