@@ -1,5 +1,4 @@
 import datetime
-import json
 from unittest.mock import Mock, patch
 
 from click.exceptions import ClickException
@@ -13,7 +12,6 @@ from anyscale.util import (
     deserialize_datetime,
     get_project_directory_name,
     get_working_dir,
-    validate_cluster_configuration,
     wait_for_session_start,
 )
 
@@ -166,20 +164,6 @@ def test_get_working_dir(project_test_data: Project) -> None:
     assert working_dir == "test_working_dir"
 
 
-def test_validate_cluster_configuration(project_test_data: Project) -> None:
-    mock_api_client = Mock()
-    cluster_config = project_test_data.initial_cluster_config
-
-    with patch("os.path.isfile", Mock(return_value=True)):
-        validate_cluster_configuration(
-            "tmp.yaml", cluster_config=cluster_config, api_instance=mock_api_client
-        )
-
-    mock_api_client.validate_cluster_api_v2_sessions_validate_cluster_post.assert_called_once_with(
-        body={"config": json.dumps(cluster_config)}
-    )
-
-
 def test_credentials_check_sanity():
     # valid credentials
     assert credentials_check_sanity("sss_abcdefg1234567")
